## 复权因子

接口：adj_factor，可以通过数据工具调试和查看数据。

更新时间：盘前9点15~20分完成当日复权因子入库

描述：本接口由Tushare自行生产，获取股票复权因子，可提取单只股票全部历史复权因子，也可以提取单日全部股票的复权因子。

积分要求：2000积分起，5000以上可高频调取

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期(YYYYMMDD，下同) |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

注：日期都填YYYYMMDD格式，比如20181010

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| ts_code | str | 股票代码 |
| trade_date | str | 交易日期 |
| adj_factor | float | 复权因子 |

接口示例

```python
pro = ts.pro_api()

#提取000001全部复权因子
df = pro.adj_factor(ts_code='000001.SZ', trade_date='')


#提取2018年7月18日复权因子
df = pro.adj_factor(ts_code='', trade_date='20180718')
```

或者

```python
df = pro.query('adj_factor',  trade_date='20180718')
```

数据样例

```python
ts_code trade_date  adj_factor
0     000001.SZ   20180809     108.031
```